Merge tag 'mm-stable-2024-05-17-19-19' of git://git.kernel.org/pub/scm/linux/kernel...
[sfrench/cifs-2.6.git] / mm / zbud.c
index 2190cc1f37b3dc93dad8c3f8df3165a59a94b38f..e9836fff9438112f9dd2fe25bc30925f49df0665 100644 (file)
--- a/mm/zbud.c
+++ b/mm/zbud.c
@@ -365,13 +365,13 @@ static void zbud_unmap(struct zbud_pool *pool, unsigned long handle)
 }
 
 /**
* zbud_get_pool_size() - gets the zbud pool size in pages
  * @pool:      pool whose size is being queried
  *
  * Returns: size in pages of the given pool.  The pool lock need not be
  * taken to access pages_nr.
  */
-static u64 zbud_get_pool_size(struct zbud_pool *pool)
+static u64 zbud_get_pool_pages(struct zbud_pool *pool)
 {
        return pool->pages_nr;
 }
@@ -410,9 +410,9 @@ static void zbud_zpool_unmap(void *pool, unsigned long handle)
        zbud_unmap(pool, handle);
 }
 
-static u64 zbud_zpool_total_size(void *pool)
+static u64 zbud_zpool_total_pages(void *pool)
 {
-       return zbud_get_pool_size(pool) * PAGE_SIZE;
+       return zbud_get_pool_pages(pool);
 }
 
 static struct zpool_driver zbud_zpool_driver = {
@@ -425,7 +425,7 @@ static struct zpool_driver zbud_zpool_driver = {
        .free =         zbud_zpool_free,
        .map =          zbud_zpool_map,
        .unmap =        zbud_zpool_unmap,
-       .total_size =   zbud_zpool_total_size,
+       .total_pages =  zbud_zpool_total_pages,
 };
 
 MODULE_ALIAS("zpool-zbud");
@@ -365,13 +365,13 @@ static void zbud_unmap(struct zbud_pool *pool, unsigned long handle)
 
 /**
- * zbud_get_pool_size() - gets the zbud pool size in pages
+ * zbud_get_pool_pages() - gets the zbud pool size in pages
  * @pool:      pool whose size is being queried
  *